package com.ibm.oti.shared;

/*
 * Licensed Materials - Property of IBM,
 *     Copyright IBM Corp. 1998, 2010  All Rights Reserved
 */

/**
 * Interface which allows users of a Helper API to filter which classes are found and stored in the cache
 * The user should provide a class which implements the interface in which the functions return true or false
 * and then pass an instance of this class to setSharingFilter() in a shared class helper.
 *
 * @see SharedClassURLHelper
 * @see SharedClassTokenHelper
 * @see SharedClassURLClasspathHelper
 */
public interface SharedClassFilter {

	/**
	 * Tests if a specified class should be stored in the shared class cache
	 *
	 * @param className		String
	 *				The fully-qualified name of the class, with the package and class names separated by '.'
	 * @return boolean
	 *				True if the class should be stored in the class cache, false otherwise.
	 */
	public boolean acceptStore(String className);

	/**
	 * Tests if the helper should try to find a specified class in the shared class cache
	 *
	 * @param className		String
	 *				The fully-qualified name of the class, with the package and class names separated by '.'
	 * @return boolean
	 *				True if the helper should try to find the class, false otherwise
	 */
	public boolean acceptFind(String className);
}
