package com.ibm.oti.shared;

import java.security.Permission;
import java.security.PermissionCollection;
import java.util.Enumeration;
import java.util.Hashtable;

/*
 * Licensed Materials - Property of IBM,
 *     Copyright IBM Corp. 1998, 2010  All Rights Reserved
 */

/**
 * Security permission collection to support SharedClassPermission
 * <p>
 * @author		OTI
 * @version		initial
 *
 * @see SharedClassPermission
 */
public class SharedClassPermissionCollection extends PermissionCollection {

	private static final long serialVersionUID = 1578153523759170949L;

	Hashtable permissions = new Hashtable(10);

	/**
	 * Add a permission to this collection
	 * <p>
	 * @author		OTI
	 * @version		initial
	 * @param		perm java.security.Permission
	 *					the Permission object to add
	 */
	public void add(Permission perm) {
		if (!isReadOnly()) {
			Permission previous = (Permission) permissions.put(perm.getName(), perm);
			// if the permission already existed but with only "read" or "write" set, then replace with both set
			if (previous != null && !previous.getActions().equals(perm.getActions()))
				permissions.put(perm.getName(), new SharedClassPermission(perm.getName(), "read,write"));
		} else throw new IllegalStateException();
	}

	/**
	 * Return permissions as an enumeration
	 * <p>
	 * @author		OTI
	 * @version		initial
	 * @return		java.util.Enumeration
	 * 					the Permissions as an enumeration
	 */
	public Enumeration elements() {
		return permissions.elements();
	}

	/**
	 * Returns true if the permission given is implied by any of the
	 * permissions in the collection
	 * <p>
	 * @author		OTI
	 * @version		initial
	 * @param		perm java.security.Permission
	 * 					the permission to check
	 * @return		java.util.Enumeration
	 * 					the Permissions as an enumeration
	 */
	public boolean implies(Permission perm) {
		Enumeration elemEnum = elements();
		while (elemEnum.hasMoreElements())
			if (((Permission) elemEnum.nextElement()).implies(perm))
				return true;
		return false;
	}

}
